@@ -1,9 +1,9 @@
 ;;; -*- Mode: LISP; Syntax: COMMON-LISP; Package: CL-PPCRE; Base: 10 -*-
-;;; $Header: /usr/local/cvsrep/cl-ppcre/api.lisp,v 1.70 2006/10/12 06:24:41 edi Exp $
+;;; $Header: /usr/local/cvsrep/cl-ppcre/api.lisp,v 1.72 2007/03/24 23:52:44 edi Exp $
 
 ;;; The external API for creating and using scanners.
 
-;;; Copyright (c) 2002-2006, Dr. Edmund Weitz. All rights reserved.
+;;; Copyright (c) 2002-2007, Dr. Edmund Weitz. All rights reserved.
 
 ;;; Redistribution and use in source and binary forms, with or without
 ;;; modification, are permitted provided that the following conditions
@@ -38,10 +38,11 @@
                                        destructive)
   (:documentation "Accepts a regular expression - either as a
 parse-tree or as a string - and returns a scan closure which will scan
-strings for this regular expression. The \"mode\" keyboard arguments
-are equivalent to the imsx modifiers in Perl. If DESTRUCTIVE is not
-NIL the function is allowed to destructively modify its first argument
-\(but only if it's a parse tree)."))
+strings for this regular expression and a list mapping registers to
+their names \(NIL stands for unnamed ones). The \"mode\" keyboard
+arguments are equivalent to the imsx modifiers in Perl. If DESTRUCTIVE
+is not NIL the function is allowed to destructively modify its first
+argument \(but only if it's a parse tree)."))
 
 #-:use-acl-regexp2-engine
 (defmethod create-scanner ((regex-string string) &key case-insensitive-mode
@@ -104,7 +105,7 @@ NIL the function is allowed to destructively modify its first argument
     (when flags
       (setq parse-tree (list :group (cons :flags flags) parse-tree))))
   (let ((*syntax-error-string* nil))
-    (multiple-value-bind (regex reg-num starts-with)
+    (multiple-value-bind (regex reg-num starts-with reg-names)
         (convert parse-tree)
       ;; simplify REGEX by flattening nested SEQ and ALTERNATION
       ;; constructs and gathering STR objects
@@ -151,30 +152,31 @@ NIL the function is allowed to destructively modify its first argument
                                           (case-insensitive-p starts-with))))))
           (declare (special end-string-offset end-anchored-p end-string))
           ;; now create the scanner and return it
-          (create-scanner-aux match-fn
-                              (regex-min-length regex)
-                              (or (start-anchored-p regex)
-                                  ;; a dot in single-line-mode also
-                                  ;; implicitely anchors the regex at
-                                  ;; the start, i.e. if we can't match
-                                  ;; from the first position we won't
-                                  ;; match at all
-                                  (and (typep starts-with 'everything)
-                                       (single-line-p starts-with)))
-                              starts-with
-                              start-string-test
-                              ;; only mark regex as end-anchored if we
-                              ;; found a non-zero-length string before
-                              ;; the anchor
-                              (and end-string-test end-anchored-p)
-                              end-string-test
-                              (if end-string-test
-                                (len end-string)
-                                nil)
-                              end-string-offset
-                              *rep-num*
-                              *zero-length-num*
-                              reg-num))))))
+          (values (create-scanner-aux match-fn
+                                      (regex-min-length regex)
+                                      (or (start-anchored-p regex)
+                                          ;; a dot in single-line-mode also
+                                          ;; implicitely anchors the regex at
+                                          ;; the start, i.e. if we can't match
+                                          ;; from the first position we won't
+                                          ;; match at all
+                                          (and (typep starts-with 'everything)
+                                               (single-line-p starts-with)))
+                                      starts-with
+                                      start-string-test
+                                      ;; only mark regex as end-anchored if we
+                                      ;; found a non-zero-length string before
+                                      ;; the anchor
+                                      (and end-string-test end-anchored-p)
+                                      end-string-test
+                                      (if end-string-test
+                                          (len end-string)
+                                          nil)
+                                      end-string-offset
+                                      *rep-num*
+                                      *zero-length-num*
+                                      reg-num)
+                  reg-names))))))
 
 #+:use-acl-regexp2-engine
 (declaim (inline create-scanner))
@@ -531,7 +533,7 @@ the scan is continued one position behind this match."
 compile time."
    (cond ((constantp regex env)
            `(all-matches (load-time-value (create-scanner ,regex))
-			 ,@rest))
+                         ,@rest))
          (t form)))
 
 (defun all-matches-as-strings (regex target-string
