@@ -1,11 +1,11 @@
 ;;; -*- Mode: LISP; Syntax: COMMON-LISP; Package: CL-PPCRE; Base: 10 -*-
-;;; $Header: /usr/local/cvsrep/cl-ppcre/regex-class.lisp,v 1.30 2006/10/12 06:24:41 edi Exp $
+;;; $Header: /usr/local/cvsrep/cl-ppcre/regex-class.lisp,v 1.32 2007/03/24 23:52:44 edi Exp $
 
 ;;; This file defines the REGEX class and some utility methods for
 ;;; this class. REGEX objects are used to represent the (transformed)
 ;;; parse trees internally
 
-;;; Copyright (c) 2002-2006, Dr. Edmund Weitz. All rights reserved.
+;;; Copyright (c) 2002-2007, Dr. Edmund Weitz. All rights reserved.
 
 ;;; Redistribution and use in source and binary forms, with or without
 ;;; modification, are permitted provided that the following conditions
@@ -122,7 +122,10 @@ appear after this repetition.")
                :reader num
                :type fixnum
                :documentation "The number of this register, starting from 0.
-This is the index into *REGS-START* and *REGS-END*."))
+This is the index into *REGS-START* and *REGS-END*.")
+          (name :initarg :name
+                :reader name
+                :documentation "Name of this register or NIL."))
       (:documentation "REGISTER objects represent register groups."))
 
     (defclass standalone (regex)
@@ -137,12 +140,15 @@ This is the index into *REGS-START* and *REGS-END*."))
                :type fixnum
                :documentation "The number of the register this
 reference refers to.")
+          (name :initarg :name
+                :accessor name
+                :documentation "The name of the register this
+reference refers to or NIL.")
           (case-insensitive-p :initarg :case-insensitive-p
                               :reader case-insensitive-p
                               :documentation "Whether we check
 case-insensitively."))
       (:documentation "BACK-REFERENCE objects represent backreferences."))
-
     (defclass char-class (regex)
          ((hash :initarg :hash
                 :reader hash
@@ -388,7 +394,8 @@ which are not of type STR."))
   (declare #.*standard-optimize-settings*)
   (make-instance 'register
                  :regex (copy-regex (regex register))
-                 :num (num register)))
+                 :num (num register)
+                 :name (name register)))
 
 (defmethod copy-regex ((standalone standalone))
   (declare #.*standard-optimize-settings*)
